@@ -21,6 +21,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "kmag.h"
+
 // include files for Qt
 #include <QApplication>
 #include <QClipboard>
@@ -46,13 +48,12 @@
 #include <KIO/FileCopyJob>
 
 // application specific includes
-#include "kmag.h"
 #include "kmagzoomview.h"
 #include "kmagselrect.h"
 
 
 KmagApp::KmagApp(QWidget* , const char* name)
-  : KXmlGuiWindow(0) // Qt::WStyle_MinMax | Qt::WType_TopLevel | Qt::WDestructiveClose | Qt::WStyle_ContextHelp | Qt::WindowCloseButtonHint | Qt::WStyle_StaysOnTop
+  : KXmlGuiWindow(nullptr) // Qt::WStyle_MinMax | Qt::WType_TopLevel | Qt::WDestructiveClose | Qt::WStyle_ContextHelp | Qt::WindowCloseButtonHint | Qt::WStyle_StaysOnTop
   , m_defaultMouseCursorType(2)
 {
   setObjectName( QLatin1String( name ) );
@@ -99,7 +100,7 @@ KmagApp::KmagApp(QWidget* , const char* name)
   readOptions();
 
   #ifndef QT_NO_PRINTER
-  m_printer = 0;
+  m_printer = nullptr;
   #endif // QT_NO_PRINTER
 }
 
@@ -410,7 +411,7 @@ void KmagApp::contextMenuEvent ( QContextMenuEvent * e )
  // show popup
  KXMLGUIFactory *factory = this->factory();
  QMenu *popup = (QMenu *)factory->container(QStringLiteral( "mainPopUp" ),this);
- if (popup != 0)
+ if (popup != nullptr)
    popup->popup(e->globalPos());
  e->accept();
 }
@@ -479,7 +480,7 @@ void KmagApp::setZoomIndex(int index)
     m_pZoomOut->setEnabled(true);
   }
 
-  if(m_zoomIndex == zoomArray.size()-1) {
+  if((int)m_zoomIndex == zoomArray.size()-1) {
     // meaning that no more zooming-in is possible
     // -> disable zoom-in icon
     m_pZoomIn->setEnabled(false);
@@ -585,25 +586,25 @@ void KmagApp::saveZoomPixmap()
       // create a temp file.. save image to it.. copy over the n/w and then delete the temp file.
       QTemporaryFile tempFile;
       if(!tempFile.open() || !m_zoomView->getImage().save(tempFile.fileName())) {
-        KMessageBox::error(0, i18n("Unable to save temporary file (before uploading to the network file you specified)."),
+        KMessageBox::error(nullptr, i18n("Unable to save temporary file (before uploading to the network file you specified)."),
                           i18n("Error Writing File"));
       } else {
         KIO::FileCopyJob *job = KIO::file_copy(QUrl::fromLocalFile(tempFile.fileName()), url);
         if(!job) {
-          KMessageBox::error(0, i18n("Unable to upload file over the network."),
+          KMessageBox::error(nullptr, i18n("Unable to upload file over the network."),
                             i18n("Error Writing File"));
         } else {
-          KMessageBox::information(0, i18n("Current zoomed image saved to\n%1", url.toDisplayString()),
+          KMessageBox::information(nullptr, i18n("Current zoomed image saved to\n%1", url.toDisplayString()),
                               i18n("Information"), QStringLiteral( "save_confirm" ));
         }
       }
 
     } else {
       if(!m_zoomView->getImage().save(url.path())) {
-        KMessageBox::error(0, i18n("Unable to save file. Please check if you have permission to write to the directory."),
+        KMessageBox::error(nullptr, i18n("Unable to save file. Please check if you have permission to write to the directory."),
                             i18n("Error Writing File"));
       } else {
-        KMessageBox::information(0, i18n("Current zoomed image saved to\n%1", url.toDisplayString()),
+        KMessageBox::information(nullptr, i18n("Current zoomed image saved to\n%1", url.toDisplayString()),
                                 i18n("Information"), QStringLiteral( "save_confirm" ));
       }
     }
@@ -740,7 +741,7 @@ void KmagApp::slotFilePrint()
 
   bool toggled(false);
 
-  if (m_printer == 0) {
+  if (m_printer == nullptr) {
     m_printer = new QPrinter();
   }
 
